import magic

from tests.conftest import SAMPLE_DIR
from tika_client.client import TikaClient
from tika_client.data_models import Document


class TestParseFormatted:
    def test_parse_docx(self, tika_client: TikaClient):
        test_file = SAMPLE_DIR / "sample.docx"
        resp = tika_client.tika.html.parse(test_file, magic.from_file(str(test_file), mime=True))

        assert isinstance(resp, Document)
        assert resp.type == "application/vnd.openxmlformats-officedocument.wordprocessingml.document"
        assert "<body><p>This is an DOCX test document, also made September 14, 2022</p>\n</body>" in resp.content

    def test_parse_docx_no_mime(self, tika_client: TikaClient):
        test_file = SAMPLE_DIR / "sample.docx"
        resp = tika_client.tika.html.parse(test_file)

        assert isinstance(resp, Document)
        assert resp.type == "application/vnd.openxmlformats-officedocument.wordprocessingml.document"
        assert "<body><p>This is an DOCX test document, also made September 14, 2022</p>\n</body>" in resp.content

    def test_parse_microsoft_word_docx(self, tika_client: TikaClient):
        test_file = SAMPLE_DIR / "microsoft-sample.docx"
        resp = tika_client.tika.html.parse(test_file, magic.from_file(str(test_file), mime=True))

        assert isinstance(resp, Document)
        assert resp.type == "application/vnd.openxmlformats-officedocument.wordprocessingml.document"
        assert (
            "<body><p>This is a sample document, generated by Microsoft Office on Wednesday, May 17, 2023.</p>\n<p>It is in English.</p>\n</body>"  # noqa: E501
            in resp.content
        )

    def test_parse_odt(self, tika_client: TikaClient):
        test_file = SAMPLE_DIR / "sample.odt"
        resp = tika_client.tika.html.parse(test_file, magic.from_file(str(test_file), mime=True))

        assert isinstance(resp, Document)
        assert resp.type == "application/vnd.oasis.opendocument.text"
        assert "<body><p>This is an ODT test document, created September 14, 2022</p>\n</body>" in resp.content


class TestParsePlain:
    def test_parse_docx(self, tika_client: TikaClient):
        test_file = SAMPLE_DIR / "sample.docx"
        resp = tika_client.tika.text.parse(test_file, magic.from_file(str(test_file), mime=True))

        assert isinstance(resp, Document)
        assert resp.type == "application/vnd.openxmlformats-officedocument.wordprocessingml.document"
        assert "This is an DOCX test document, also made September 14, 2022" in resp.content

    def test_parse_odt(self, tika_client: TikaClient):
        test_file = SAMPLE_DIR / "sample.odt"
        resp = tika_client.tika.text.parse(test_file, magic.from_file(str(test_file), mime=True))

        assert isinstance(resp, Document)
        assert resp.type == "application/vnd.oasis.opendocument.text"
        assert "This is an ODT test document, created September 14, 2022" in resp.content
